package de.hft.stuttgart.citydoctor2.connect.edge;



import de.hft.stuttgart.citydoctor2.connect.edge.CppReferenceHandlingBase;
import de.hft.stuttgart.citydoctor2.connect.edge.NativePointerCastException;

public class AutoProSettingsMerge extends CppReferenceHandlingBase {
	private native long createCppClass(
				boolean useMerge,
				boolean exportIntermediateStages,
				boolean printMergeInfo,
				double  eps_PointEquality,
				double  eps_Parallelity
			)
			throws OutOfMemoryError;

	private native void disposeCppClass(long ptrToCppAutoPro)
			throws NativePointerCastException;

	private boolean useMerge;
	private boolean exportIntermediateStages;
	private boolean printMergeInfo;
	private double eps_PointEquality;
	private double eps_Parallelity;
	
	public AutoProSettingsMerge() {
		setUseMerge(false);
		setExportIntermediateStages(false);
		setPrintMergeInfo(false);
		setEps_PointEquality(0.01);
		setEps_Parallelity(0.01);
	}

	/**
	 * Creates an C++ feature object
	 * 
	 * @throws IllegalStateException
	 *             Thrown if the encapsulated "long-Pointer" isn't 0
	 * @throws NativeOutOfMemoryException
	 *             If there is no more memory on the native side
	 * 
	 * @see {@link disposeCppObject}
	 * @see de.hft.stuttgart.citydoctor.connect.edGe.CppReferenceHandlingBase#createCppObject()
	 */
	public void createCppObject() throws IllegalStateException,
			OutOfMemoryError {
		if (0L != ptrToCppObject) {
			throw new IllegalStateException(
					"Can't create new C++ object, there is allready one!");
		}
		// Maybe an exception is thrown
		long tmpPointer = createCppClass(
				isUseMerge(),
				isExportIntermediateStages(),
				isPrintMergeInfo(),
				getEps_PointEquality(),
				getEps_Parallelity()
				);
		ptrToCppObject = tmpPointer;
	}

	@Override
	public void disposeCppObject() throws NativePointerCastException {
		if (0L != ptrToCppObject) {
			disposeCppClass(ptrToCppObject);
			ptrToCppObject = 0L;
		}
	}

	public void setUseMerge(boolean useMerge) {
		this.useMerge = useMerge;
	}

	public void setExportIntermediateStages(boolean exportIntermediateStages) {
		this.exportIntermediateStages = exportIntermediateStages;
	}	
	
	public void setPrintMergeInfo(boolean printMergeInfo) {
		this.printMergeInfo = printMergeInfo;
	}

	public void setEps_PointEquality(double eps_PointEquality) {
		this.eps_PointEquality = eps_PointEquality;
	}		
	
	public void setEps_Parallelity(double eps_Parallelity) {
		this.eps_Parallelity = eps_Parallelity;
	}
	

	public boolean isUseMerge() {
		return useMerge;
	}
	
	public boolean isExportIntermediateStages() {
		return exportIntermediateStages;
	}	
	
	public boolean isPrintMergeInfo() {
		return printMergeInfo;
	}
	
	public double getEps_PointEquality() {
		return eps_PointEquality;
	}
	
	public double getEps_Parallelity() {
		return eps_Parallelity;
	}

}
